@@ -7,9 +7,16 @@ import tqdm
 import os
 import time
 import json
-import maintain_PlatoUtils
 import requests
 import gc
+import random
+from string import punctuation
+import argparse
+
+parser = argparse.ArgumentParser(description='manual to this script')
+current_path = os.path.dirname(__file__)
+if len(current_path)==0:
+    current_path="."
 
 def wrapNebula2Df(nebulaObj):
     '''将platoDB查询到的对象转为df'''
@@ -19,9 +26,7 @@ def wrapNebula2Df(nebulaObj):
         columnList = [colItem.decode("utf8") for colItem in nebulaObj.column_names]
     else:
         return pd.DataFrame([])
-    end=time.time()
     
-    start=time.time()
     dataList = []
     if nebulaObj.rows is not None:
         gc.disable()
@@ -36,7 +41,6 @@ def wrapNebula2Df(nebulaObj):
         gc.enable()
     else:
         return pd.DataFrame([])
-    end=time.time()
     
     return pd.DataFrame(dataList, columns=columnList).drop_duplicates()
 
@@ -61,38 +65,50 @@ def delEdge(gClient,sysIdList,edgeType="*"):
         relList=relDf.values.flatten().tolist()
     else:
         relList=[edgeType]
-    for relItem in relList:
+    for relItem in tqdm.tqdm(relList,desc="del edges"):
         for srcSysIdItem in sysIdList:
-            relTailSysIdDf=wrapNebula2Df(gClient.execute_query("GO FROM {srcSysId} OVER {edgeName} BIDIRECT YIELD {edgeName}._dst AS tgtSysId".format(
-                srcSysId=srcSysIdItem,
-                edgeName=relItem)))
+            searchRelStr="GO FROM {srcSysId} OVER {edgeName} BIDIRECT YIELD {edgeName}._dst AS tgtSysId".format(
+                                                                                                                srcSysId=srcSysIdItem,
+                                                                                                                edgeName=relItem)
+            print(searchRelStr)
+            relTailSysIdDf=wrapNebula2Df(gClient.execute_query(searchRelStr))
             if relTailSysIdDf.shape[0]>0:
                 relTailSysIdList=relTailSysIdDf["tgtSysId"].values.flatten().tolist()
                 delOrderGroupStr=",".join(["{}->{}".format(srcSysIdItem,tailSysIdItem) for tailSysIdItem in relTailSysIdList])
                 delReverseGroupStr=",".join(["{}->{}".format(tailSysIdItem,srcSysIdItem) for tailSysIdItem in relTailSysIdList])
                 delGroupStr=",".join([delOrderGroupStr,delReverseGroupStr])
-                gClient.execute_query("DELETE EDGE {} {}".format(relItem,delGroupStr))
+                delStr="DELETE EDGE {} {}".format(relItem,delGroupStr)
+                print(delStr)
+                gClient.execute_query(delStr)
 
 def delVertex(gClient,sysIdList,delRel=True):
     '''（关联）删除节点'''
     delReq={"data":[],"error_code":0}
     if delRel==True:
-        relDf=wrapNebula2Df(gClient.execute_query("SHOW EDGES"))["Name"]
-        relList=relDf.values.flatten().tolist()
-        for relItem in relList:
-            for srcSysIdItem in sysIdList:
-                relTailSysIdDf=wrapNebula2Df(gClient.execute_query("GO FROM {srcSysId} OVER {edgeName} BIDIRECT YIELD {edgeName}._dst AS tgtSysId".format(
-                    srcSysId=srcSysIdItem,
-                    edgeName=relItem)))
-                if relTailSysIdDf.shape[0]>0:
-                    relTailSysIdList=relTailSysIdDf["tgtSysId"].values.flatten().tolist()
-                    delOrderGroupStr=",".join(["{}->{}".format(srcSysIdItem,tailSysIdItem) for tailSysIdItem in relTailSysIdList])
-                    delReverseGroupStr=",".join(["{}->{}".format(tailSysIdItem,srcSysIdItem) for tailSysIdItem in relTailSysIdList])
-                    delGroupStr=",".join([delOrderGroupStr,delReverseGroupStr])
-                    gClient.execute_query("DELETE EDGE {} {}".format(relItem,delGroupStr))
-    for batchI in range(0,len(sysIdList),50): 
+        relDf=wrapNebula2Df(gClient.execute_query("SHOW EDGES"))
+        if relDf.shape[0]>0:
+            relList=relDf["Name"].values.flatten().tolist()
+            for relItem in tqdm.tqdm(relList,desc="del edges with vertexes"):
+                for srcSysIdItem in tqdm.tqdm(sysIdList,desc="del srcs from edges with vertexes"):
+                    relTailStr="GO FROM {srcSysId} OVER {edgeName} BIDIRECT YIELD {edgeName}._dst AS tgtSysId".format(
+                        srcSysId=srcSysIdItem,
+                        edgeName=relItem)
+                    # print(relTailStr)
+                    relTailSysIdDf=wrapNebula2Df(gClient.execute_query(relTailStr))
+                    if relTailSysIdDf.shape[0]>0:
+                        relTailSysIdList=relTailSysIdDf["tgtSysId"].values.flatten().tolist()
+                        delOrderGroupStr=",".join(["{}->{}".format(srcSysIdItem,tailSysIdItem) for tailSysIdItem in relTailSysIdList])
+                        delReverseGroupStr=",".join(["{}->{}".format(tailSysIdItem,srcSysIdItem) for tailSysIdItem in relTailSysIdList])
+                        delGroupStr=",".join([delOrderGroupStr,delReverseGroupStr])
+                        delStr="DELETE EDGE {} {}".format(relItem,delGroupStr)
+                        # print(delStr)
+                        gClient.execute_query(delStr)
+    # print(sysIdList)
+    for batchI in tqdm.tqdm(range(0,len(sysIdList),50),desc="del vertexes"): 
         delVerGroupStr=",".join([str(sysIdItem) for sysIdItem in sysIdList[batchI:batchI+50]])
-        delReq=gClient.execute_query("DELETE VERTEX {}".format(delVerGroupStr))
+        delStr="DELETE VERTEX {}".format(delVerGroupStr)
+        # print(delStr)
+        delReq=gClient.execute_query(delStr)
     return delReq
                 
 def existTag(nodeType,nodeIdAttr,nodeName,gClient):
@@ -107,6 +123,8 @@ def existTag(nodeType,nodeIdAttr,nodeName,gClient):
             )))
             if searchTagDf.shape[0]>0:
                 return True
+            else:
+                passTag+=1
         except:
             passTag+=1
     return False
@@ -301,6 +319,80 @@ def existEdge(headType,headIdAttr,headIdVal,tailType,tailIdAttr,tailIdVal,edgeTy
         return True
     return False
 
+def addTokenForEntities(gClient,gDBName,nodeIdAttrList,tabuList=[],projectName="",email=""):
+    '''构建实体的token实体'''
+    if "csv2platodb" not in os.listdir("."):
+        os.mkdir("csv2platodb")
+        
+    if len(projectName)==0:
+        projectName="tmp_{}".format(int(time.time()*1000))
+        os.mkdir("csv2platodb/{}".format(projectName))
+    
+    if len(tabuList)==0:
+        tabuList=list(punctuation)+["“","”","‘","’","，","。"]
+    
+    # 构建节点和边的数据
+    schemaVertex=[]
+    schemaEdge=[]
+    for nodeItdPairItem in nodeIdAttrList:
+        
+        nodeType=nodeItdPairItem.split(".")[0]
+        nodeIdAttr=nodeItdPairItem.split(".")[1]
+        
+        tgtNameDf=wrapNebula2Df(gClient.execute_query("LOOKUP ON {nodeType} WHERE {nodeType}.{nodeIdAttr}!='不可能的名字' \
+                                                        YIELD {nodeType}.{nodeIdAttr} AS tgtName".format(nodeType=nodeType,
+                                                                                                          nodeIdAttr=nodeIdAttr)))
+        srcTokenPairList=[]
+        tokenInfoList=[]
+        for tgtNameItem in tqdm.tqdm(tgtNameDf["tgtName"].values.flatten().tolist(),desc=nodeType):
+            tgtNameItem=tgtNameItem.lower()
+            for tgtNameTokenItem in tgtNameItem:
+                if tgtNameTokenItem not in tabuList:
+                    tokenInfoList.append({"Name":tgtNameTokenItem})
+                srcTokenPairList.append({"headEntity":tgtNameTokenItem,"tailEntity":tgtNameTokenItem})
+        srcTokenPairDf=pd.DataFrame(srcTokenPairList)
+        tokenInfoDf=pd.DataFrame(tokenInfoList)
+            
+        tokenInfoDf.to_csv(current_path+"/csv2platodb/{}/tokenInfo_{}.csv".format(projectName,nodeType),index=None)
+        srcTokenPairDf.to_csv(current_path+"/csv2platodb/{}/consistOfRel_{}.csv".format(projectName,nodeType),index=None)
+        
+        schemaVertex.append({ 
+                                "file_name":"tokenInfo_{}.csv".format(projectName,nodeType),
+                                "node_type":"Token",
+                                "id_col":"Name", 
+                                "csv2plato_attr_map":{ 
+                                    "Name":"Name"
+                                },
+                                "attr_type_map":{ 
+                                    "Name":"string"
+                                }
+                            })
+        schemaEdge.append({
+                                "file_name":"consistOfRel_{}.csv".format(projectName,nodeType),
+                                "edge_type":"consistOf",
+                                "src_type":nodeType,
+                                "tgt_type":"Token",
+                                "src_id":"headEntity",
+                                "tgt_id":"tailEntity",
+                                "csv2plato_attr_map":{},
+                                "attr_type_map":{}
+                            })
+    # 构建数据schema
+    VESchema={
+        "gDbName":gDBName,
+        "vertex":schemaVertex,
+        "edge":schemaEdge,
+        "email":email
+    }
+    if len(email)==0:
+        VESchema.pop("email")
+    
+    with open(current_path+"/csv2platodb/{}/rawSchema.json".format(projectName,nodeType),"w+",encoding="utf8") as VESchemaFile:
+        json.dump(VESchema,VESchemaFile)
+    
+    print("本地文件生成")
+    return VESchema
+
 if __name__=="__main__":
     
     srcGHost=""
@@ -360,4 +452,4 @@ if __name__=="__main__":
     #                      edgeTypeList=[],
     #                      srcVertexKeynameDict=srcVertexKeynameDict,csv2platoDTypeDict=csv2platoDTypeDict)
     
-    # pass
\ No newline at end of file
+    # pass
