@@ -7,7 +7,12 @@ import http.client
 import mimetypes
 from codecs import encode
 import numpy as np
+import argparse
+import joblib
 from maintain_PlatoUtils.maintain_PlatoUtils import existTag,wrapNebula2Df,existEdge,delEdge,delVertex
+import joblib
+import sys
+import os.path as osp
 
 csv2platoDTypeDict={
     "object":"string",
@@ -26,7 +31,14 @@ def evalDataType(myDf):
 
 def uploadFolder(dataFolder,platoUrl):
     
-    if "uploadSchema.json" in os.listdir(dataFolder):
+    from sys import _getframe
+    from pathlib import Path
+    frame = _getframe(1)
+    curr_file = Path(frame.f_code.co_filename)
+    a=str(curr_file.parent.joinpath(dataFolder).resolve())
+    print(a)
+    
+    if "uploadSchema.json" in dataFolder:
         
         with open(os.path.join(dataFolder,"uploadSchema.json").replace("\\","/"),"r",encoding="utf8") as uploadSchemaFile:
             uploadSchemaJson=json.load(uploadSchemaFile)
@@ -99,7 +111,7 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
     if csvFolder[-1]=="/":
         csvFolder=csvFolder[:-1]
     
-    for vertexI,_ in enumerate(rawSchemaJson["vertex"]):
+    for vertexI,_ in tqdm.tqdm(enumerate(rawSchemaJson["vertex"]),desc="vertex"):
         rawSchemaJson["vertex"][vertexI]["file_path"]=csvFolder+"/"+rawSchemaJson["vertex"][vertexI]["file_name"]
         csvDfItem=pd.read_csv(rawSchemaJson["vertex"][vertexI]["file_path"])
         csvDfItem[rawSchemaJson["vertex"][vertexI]["id_col"]]=csvDfItem[rawSchemaJson["vertex"][vertexI]["id_col"]].astype(str)
@@ -114,10 +126,12 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
         if vertexDataProcess=="cover":
             nodeType=rawSchemaJson["vertex"][vertexI]["node_type"]
             nodeIdAttr=rawSchemaJson["vertex"][vertexI]["id_col"]
-            sysIdList=wrapNebula2Df(gClient.execute_query("LOOKUP ON {nodeType} WHERE {nodeType}.{nodeIdAttrKey}!='不可能的名字'".format(
-                                                                                                                                        nodeType=nodeType,
-                                                                                                                                        nodeIdAttrKey=nodeIdAttr
-                                                                                                                                    ))).values.flatten().tolist()
+            sysVertexSearchStr="LOOKUP ON {nodeType} WHERE {nodeType}.{nodeIdAttrKey}!='不可能的名字'".format(
+                                                                                                                    nodeType=nodeType,
+                                                                                                                    nodeIdAttrKey=nodeIdAttr
+                                                                                                                )
+            # print(sysVertexSearchStr)
+            sysIdList=wrapNebula2Df(gClient.execute_query(sysVertexSearchStr)).values.flatten().tolist()
             delVertex(gClient,sysIdList)
         elif vertexDataProcess=="escape":
             pass
@@ -150,19 +164,30 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
                 nodeItemGInfoDfList.append(nodeItemGInfoDf)
             nodeItemGInfoDf=pd.concat(nodeItemGInfoDfList)
             
-            for colItem in nodeItemCInfoDf.columns:
-                idAttrKey=rawSchemaJson["vertex"][vertexI]["id_col"]
-                if colItem !=  idAttrKey:
-                    changedIdList=nodeItemCInfoDf.loc[(nodeItemCInfoDf[colItem].isna())|
-                                                    (nodeItemCInfoDf[colItem]=="null")|
-                                                    (nodeItemCInfoDf[colItem]==""),idAttrKey].values.flatten().tolist()
-                    nodeItemCInfoDf.loc[nodeItemCInfoDf[idAttrKey].str.isin(changedIdList),colItem]=\
-                        nodeItemGInfoDf.loc[nodeItemGInfoDf[idAttrKey].str.isin(changedIdList),colItem]
+            # print("nodeItemCInfoDf:",nodeItemCInfoDf.columns)
+            # print("nodeItemGInfoDf:",nodeItemGInfoDf.columns)
+            if nodeItemGInfoDf.shape[0]>0:
+                for colItem in nodeItemCInfoDf.columns:
+                    if colItem in nodeItemGInfoDf:
+                        idAttrKey=rawSchemaJson["vertex"][vertexI]["id_col"]
+                        if colItem !=  idAttrKey:
+                            changedIdList=nodeItemCInfoDf.loc[(nodeItemCInfoDf[colItem].isna())|
+                                                            (nodeItemCInfoDf[colItem]=="null")|
+                                                            (nodeItemCInfoDf[colItem]==""),idAttrKey].values.flatten().tolist()
+
+                            cIdDf=nodeItemCInfoDf.loc[nodeItemCInfoDf[idAttrKey].isin(changedIdList),idAttrKey]
+                            gIdDf=nodeItemGInfoDf.loc[nodeItemGInfoDf[idAttrKey].isin(changedIdList),idAttrKey]
+                            
+                            # print(nodeItemCInfoDf.loc[nodeItemCInfoDf[idAttrKey].isin(gIdDf),:])
+                            # print(nodeItemGInfoDf.loc[nodeItemGInfoDf[idAttrKey].isin(gIdDf),:])
+
+                            nodeItemCInfoDf.loc[nodeItemCInfoDf[idAttrKey].isin(gIdDf),colItem]=\
+                                nodeItemGInfoDf.loc[nodeItemGInfoDf[idAttrKey].isin(gIdDf),colItem].values
             
             csvDfItem=nodeItemCInfoDf
         elif vertexAttrProcess=="cover":
             pass
-        # print(csvDfItem.head())
+        # print("csvDfItem:",csvDfItem.head())
         
         csvDfItem.to_csv(rawSchemaJson["vertex"][vertexI]["file_path"],index=None)
         rawSchemaJson["vertex"][vertexI]["old_id_col"]=rawSchemaJson["vertex"][vertexI]["id_col"]
@@ -175,7 +200,7 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
             CPAttrTypeDict=evalDataType(vertexItemDf)
             rawSchemaJson["vertex"][vertexI]["attr_type_map"]=CPAttrTypeDict
 
-    for edgeI,_ in enumerate(rawSchemaJson["edge"]):
+    for edgeI,_ in tqdm.tqdm(enumerate(rawSchemaJson["edge"]),desc="edge"):
         rawSchemaJson["edge"][edgeI]["file_path"]=csvFolder+"/"+rawSchemaJson["edge"][edgeI]["file_name"]
         csvDfItem=pd.read_csv(rawSchemaJson["edge"][edgeI]["file_path"])
         srcType=rawSchemaJson["edge"][edgeI]["src_type"]
@@ -197,7 +222,7 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
                                                                                                                             ))).values.tolist()
             for batchI in tqdm.tqdm(range(0,len(oldSysId),1024),desc="head edges control-cover"):
                 oldSysIdGroup=[str(oldSysIdItem) for oldSysIdItem in oldSysId[batchI:batchI+1024]]
-                delEdge(oldSysIdGroup)
+                delEdge(gClient,oldSysIdGroup)
         elif headEdgeDataProcess=="escape":
             pass
 
@@ -209,7 +234,7 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
                                                                                                                             ))).values.tolist()
             for batchI in tqdm.tqdm(range(0,len(oldSysId),1024),desc="tail edges control-cover"):
                 oldSysIdGroup=[str(oldSysIdItem) for oldSysIdItem in oldSysId[batchI:batchI+1024]]
-                delEdge(oldSysIdGroup)
+                delEdge(gClient,oldSysIdGroup)
         elif tailEdgeDataProcess=="escape":
             pass
 
@@ -235,7 +260,7 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
                         newStList.append([srcKV,tgtKV])
                         csvDfItemRow={srcIdAttr:srcKV,tgtIdAttr:tgtKV}
                         csvDfItemList.append(csvDfItemRow)
-            csvDfItem=pd.concat(csvDfItemList)
+            csvDfItem=pd.DataFrame(csvDfItemList)
         elif edgeAttrDataProcess=="plus":
             htList=json.loads(csvDfItem.to_json(orient="records"))
             newHTList=[]
@@ -283,7 +308,7 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
     
     return rawSchemaJson
 
-def buildGraphDB(gClient,uploadSchemaJson,realDbName=None):
+def buildGraphDB(gClient,uploadSchemaJson,realDbName=None,force=False):
     
     typeDefaultDict={
         "string":"null",
@@ -291,10 +316,15 @@ def buildGraphDB(gClient,uploadSchemaJson,realDbName=None):
         "int":0
     }
     
+    if force==False:
+        isexist="IF EXIST"
+    else:
+        isexist=""
+
     if realDbName is None:
         realDbName=uploadSchemaJson["gDbName"]
     
-    queryList=["DROP SPACE IF EXISTS {};CREATE SPACE IF NOT EXISTS {}".format(realDbName,realDbName)]
+    queryList=["DROP SPACE {} {};CREATE SPACE IF NOT EXISTS {}".format(isexist,realDbName,realDbName)]
     
     for vertexInfo in uploadSchemaJson["vertex"]:
         attrNameTypeGroup=[(vertexInfo["csv2plato_attr_map"][attrKeyItem],
